<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * the first page to view the homeroom
 *
 * @author  Fumi Iseki
 * @license GNU Public License
 * @package mod_homeroom
 */

require_once('../../config.php');
require_once('lib.php');
include_once('homeroom_lib.php');
require_once($CFG->libdir.'/tablelib.php');

homeroom_init_session();
$SESSION->homeroom->is_started = false;

//
$id 	  = required_param('id', PARAM_INT);
$courseid = optional_param('courseid', 0, PARAM_INT);
$crsid	  = optional_param('crsid', 1, PARAM_INT);
$action   = optional_param('action', 'list', PARAM_ALPHAEXT);
$sort	  = optional_param('sort', 'lastname', PARAM_ALPHA);
$order	  = optional_param('order', 'ASC', PARAM_ALPHA);
$userid   = optional_param('userid', 0, PARAM_INT);
$printing = optional_param('printing', '', PARAM_ALPHA);

$urlparams['id'] 	   = $id;
$urlparams['action']   = $action;
if ($userid) $urlparams['userid']   = $userid;
$urlparams['courseid'] = $courseid;
$urlparams['crsid']    = $crsid;
$urlparams['sort']	   = $sort;
$urlparams['order']	   = $order;
if ($printing) $urlparams['printing'] = $printing;

//
$wwwBaseUrl = $CFG->wwwroot.'/mod/homeroom/view.php?id='.$id;


////////////////////////////////////////////////////////
//get the objects
if (! $cm = get_coursemodule_from_id('homeroom', $id)) {
	print_error('invalidcoursemodule');
}
if (! $course = $DB->get_record('course', array('id'=>$cm->course))) {
	print_error('coursemisconf');
}
if (! $homeroom = $DB->get_record('homeroom', array('id'=>$cm->instance))) {
	print_error('invalidcoursemodule');
}
if (!$courseid) $courseid = $course->id;

$name_pattern = $homeroom->namepattern;
$attendPlugin = $homeroom->attendplugin;
$mcontext = context_module::instance($cm->id);
$ccontext = context_course::instance($courseid);


////////////////////////////////////////////////////////
// Check
require_login($course, true, $cm);
//
$homeroom_view_cap = false;
if (has_capability('mod/homeroom:view', $mcontext)) {
	$homeroom_view_cap = true;
}


///////////////////////////////////////////////////////////////////////////
// URL
$strhomerooms = get_string('modulenameplural', 'homeroom');
$strhomeroom  = get_string('modulename', 'homeroom');

$this_url = new moodle_url($wwwBaseUrl);
$this_url->params($urlparams);
$log_url  = explode('/', $this_url);
add_to_log($course->id, 'homeroom', $action, end($log_url), 'homeroom_id='.$homeroom->id);


///////////////////////////////////////////////////////////////////////////
// Print the page header
$PAGE->navbar->add(get_string('homeroom:list', 'homeroom'));
$PAGE->set_url($this_url);
$PAGE->set_title(format_string($homeroom->name));
$PAGE->set_heading(format_string($course->fullname));

if ( $printing) $PAGE->set_pagelayout('print');
echo $OUTPUT->header();

$current_tab = $action;
if (!$printing) require('tabs.php');
if ($userid==0) $userid = $USER->id;
$fullname = homeroom_get_user_name($userid, $name_pattern);


///////////////////////////////////////////////////////////////////////////
// Print the main part of the page

//echo $OUTPUT->heading(format_text($homeroom->name));

// Check
if (!$homeroom_view_cap) {
	homeroom_print_error_messagebox('homeroom_is_disable', $crsid, 'course');
	exit;
}

$members = homeroom_get_members($homeroom->id, $USER->id);
//if (!$members) {
//	homeroom_print_error_messagebox('homeroom_is_disable', $crsid, 'course');
//	exit;
//}


///////////////////////////////////////////////////////////////////////////
// ユーザ表示
//   出欠を閲覧することが可能な学生の一覧を表示
//
if ($action=='list') {
	//
	$students = array();
	if ($name_pattern=='fullname') {
		if ($sort=='lastname') {
			foreach($members as $member) {
				$member->name = homeroom_get_user_name($member, 'fullname');
				$students[$member->lastname] = $member;
			}
		}
		else {
			foreach($members as $member) {
				$member->name = homeroom_get_user_name($member, 'fullname');
				$students[$member->firstname] = $member;
			}
		}
	}
	else {
		foreach($members as $member) {
			$member->name = homeroom_get_user_name($member, $name_pattern);
			$students[$member->name] = $member;
		}
	}
	//
	if ($order=='ASC') ksort ($students);
	else			   krsort($students);
	//
	require_once('homeroom_user_list.php');
	echo $OUTPUT->box_start('generalbox boxaligncenter boxwidthwide');
	homeroom_print_user_list($students, $name_pattern, $sort, $order);
	echo $OUTPUT->box_end();
}



///////////////////////////////////////////////////////////////////////////
// コースリスト
//   １ユーザの全てのコースのリストを表示する．
//
else if ($action=='crslist') {
	$permit = homeroom_has_show_permit($userid, $members);
	if (!$permit) die();

	require_once('homeroom_course_list.php');
	$user = $DB->get_record('user', array('id'=>$userid));
	homeroom_print_course_list($user, $sort, $order);
}



///////////////////////////////////////////////////////////////////////////
// ユーザ レポート
//   １ユーザの全てのコースの出席を表示する．
//
else if ($action=='report') {
	$permit = homeroom_has_show_permit($userid, $members);
	if (!$permit) die();

	require_once('homeroom_user_report.php');
	$user = $DB->get_record('user', array('id'=>$userid));
	homeroom_print_user_report($user, $sort, $order);
}



///////////////////////////////////////////////////////////////////////////
// コースレポート
//   １ユーザの特定のコースの出席を表示する．
//
else if ($action=='crsreport') {
	$permit = homeroom_has_show_permit($userid, $members);
	if (!$permit) die();

	require_once('homeroom_course_report.php');
	$ccrs = $DB->get_record('course', array('id'=>$crsid));
	$user = $DB->get_record('user',   array('id'=>$userid));
	homeroom_print_course_report($user, $ccrs, $printing);
	if ($printing) die();
}




/*
///////////////////////////////////////////////////////////////////////////
// 設定
*/






/////////////////////////////////////////
if (empty($module)) $module = new stdClass();
include('version.php');
//
echo '<div align="center"><br />';
echo '<a href="'.get_string('homeroom_url', 'homeroom').'" target="_blank"><i>mod_homeroom '.$module->release.'</i></a>';
echo '<br /><br />';
echo '</div>';


///////////////////////////////////////////////////////////////////////////
/// Finish the page
echo $OUTPUT->footer();

